-- -----------------------------------------------------------------------------
Library IEEE;
Use     IEEE.Std_Logic_1164.All;
-- -----------------------------------------------------------------------------

-- -----------------------------------------------------------------------------
Entity ReplaceWith_EntityName Is
-- -----------------------------------------------------------------------------
Port (
    -- System
    CLK_I            : In  Std_Logic;
    RST_I            : In  Std_Logic;
    -- Usb Description Serial Number Source
    ONE_WIRE         : InOut Std_Logic;

    -- Usb Interface
    USB_D           : InOut Std_Logic_Vector(7 Downto 0);
    USB_FIFOADR0    : Out   Std_Logic;
    USB_FIFOADR1    : Out   Std_Logic;
    USB_FIFOADR2    : Out   Std_Logic;
    USB_FLAGA       : In    Std_Logic;
    USB_FLAGB       : In    Std_Logic;
    USB_FLAGC       : In    Std_Logic;
    USB_FLAGD_CS_N  : InOut Std_Logic;
    USB_IFCLK       : Out   Std_Logic;
    USB_INT_N       : In    Std_Logic;
    USB_PKTEND      : Out   Std_Logic;
    USB_RD_N        : Out   Std_Logic;
    USB_READY       : In    Std_Logic;
    USB_RESET_N     : Out   Std_Logic;
    USB_SLOE        : Out   Std_Logic;
    USB_VBUS        : In    Std_Logic;
    USB_WR_N        : Out   Std_Logic;

    -- JTAG Interface
    JTAG_SOFT_TCK    : Out Std_Logic;
    JTAG_SOFT_TDI    : Out Std_Logic;
    JTAG_SOFT_TDO    : In  Std_Logic;
    JTAG_SOFT_TMS    : Out Std_Logic;

    -- System SPI Interface
    --ReplaceWith_SpiDevicesDeclaration

    -- User SPI Interface
    DB_SPI_CLK       : In  Std_Logic;
    DB_SPI_DOUT      : Out Std_Logic;
    DB_SPI_DIN       : In  Std_Logic;
    DB_SPI_MODE      : In  Std_Logic;
    DB_SPI_SEL       : In  Std_Logic
);
-- -----------------------------------------------------------------------------
End;
-- -----------------------------------------------------------------------------

-- -----------------------------------------------------------------------------
Architecture RTL Of ReplaceWith_EntityName Is
-- -----------------------------------------------------------------------------

    -- -------------------------------------------------------------------------
    Component PC_INTERFACE_OWM Is
    Port (
        CLK_I                          : In    STD_LOGIC;
        CONFIG_CLK_SCALER_VALUE        : In    STD_LOGIC_VECTOR(7 DOWNTO 0);
        CONFIG_READ_STATUS_CYCLES      : In    STD_LOGIC_VECTOR(7 DOWNTO 0);
        CONFIG_TM_ADDRESS_SETUP_CYCLES : In    STD_LOGIC_VECTOR(7 DOWNTO 0);
        CONFIG_TM_RESET_CYCLES         : In    STD_LOGIC_VECTOR(7 DOWNTO 0);
        CONFIG_TM_STROBE_HIGH_CYCLES   : In    STD_LOGIC_VECTOR(7 DOWNTO 0);
        CONFIG_TM_STROBE_LOW_CYCLES    : In    STD_LOGIC_VECTOR(7 DOWNTO 0);
        CONFIG_TM_WRITE_HIGH_CYCLES    : In    STD_LOGIC_VECTOR(7 DOWNTO 0);
        DB_SPI_CLK                     : In    STD_LOGIC;
        DB_SPI_MISO                    : Out   STD_LOGIC;
        DB_SPI_MODE                    : In    STD_LOGIC;
        DB_SPI_MOSI                    : In    STD_LOGIC;
        DB_SPI_SEL                     : In    STD_LOGIC;
        HUSB_D_EN                      : Out   STD_LOGIC;
        HUSB_D_IN                      : In    STD_LOGIC_VECTOR(7 DOWNTO 0);
        HUSB_D_OUT                     : Out   STD_LOGIC_VECTOR(7 DOWNTO 0);
        HUSB_FIFOADR0                  : Out   STD_LOGIC;
        HUSB_FIFOADR1                  : Out   STD_LOGIC;
        HUSB_FIFOADR2                  : Out   STD_LOGIC;
        HUSB_FLAGA                     : In    STD_LOGIC;
        HUSB_FLAGB                     : In    STD_LOGIC;
        HUSB_FLAGC                     : In    STD_LOGIC;
        HUSB_FLAGD_CS_N                : Out   STD_LOGIC;
        HUSB_IFCLK                     : Out   STD_LOGIC;
        HUSB_INT_N                     : In    STD_LOGIC;
        HUSB_PKTEND                    : Out   STD_LOGIC;
        HUSB_RD_N                      : Out   STD_LOGIC;
        HUSB_READY                     : In    STD_LOGIC;
        HUSB_RESET_N                   : Out   STD_LOGIC;
        HUSB_SLOE                      : Out   STD_LOGIC;
        HUSB_VBUS                      : In    STD_LOGIC;
        HUSB_WR_N                      : Out   STD_LOGIC;
        JTAG_SOFT_TCK                  : Out   STD_LOGIC;
        JTAG_SOFT_TDI                  : Out   STD_LOGIC;
        JTAG_SOFT_TDO                  : In    STD_LOGIC;
        JTAG_SOFT_TMS                  : Out   STD_LOGIC;
        MEM_DAT_ADR                    : Out   STD_LOGIC_VECTOR( 7 DOWNTO 0);
        MEM_DAT_I                      : In    STD_LOGIC_VECTOR(15 DOWNTO 0);
        MEM_DAT_O                      : Out   STD_LOGIC_VECTOR(15 DOWNTO 0);
        MEM_WE_O                       : Out   STD_LOGIC;
        ONE_WIRE_EN                    : Out   STD_LOGIC;
        ONE_WIRE_IN                    : In    STD_LOGIC;
        ONE_WIRE_OUT                   : Out   STD_LOGIC;
        RST_I                          : In    STD_LOGIC;
        SN_ADR_O                       : Out   STD_LOGIC_VECTOR( 7 DOWNTO 0);
        SN_DAT_I                       : In    STD_LOGIC_VECTOR(15 DOWNTO 0);
        SN_DAT_O                       : Out   STD_LOGIC_VECTOR(15 DOWNTO 0);
        SN_WE_O                        : Out   STD_LOGIC;
        SPI_CLK                        : Out   STD_LOGIC_VECTOR(30 DOWNTO 0);
        SPI_MISO                       : In    STD_LOGIC_VECTOR(30 DOWNTO 0);
        SPI_MOSI                       : Out   STD_LOGIC_VECTOR(30 DOWNTO 0);
        SPI_SEL                        : Out   STD_LOGIC_VECTOR(30 DOWNTO 0)
    );
    End Component;
    -- -------------------------------------------------------------------------

    -- -------------------------------------------------------------------------
    Component ReplaceWith_EntityName_USB_DESCR_MEMORY Is
    Port (
        CLKA  : In  Std_Logic;
        DINA  : In  Std_Logic_Vector(15 Downto 0);
        DOUTA : Out Std_Logic_Vector(15 Downto 0);
        ADDRA : In  Std_Logic_Vector( 7 Downto 0);
        WEA   : In  Std_Logic;
        CLKB  : In  Std_Logic;
        DINB  : In  Std_Logic_Vector(15 Downto 0);
        DOUTB : Out Std_Logic_Vector(15 Downto 0);
        ADDRB : In  Std_Logic_Vector( 7 Downto 0);
        WEB   : In  Std_Logic
    );
    End Component;
    -- -------------------------------------------------------------------------

    -- -------------------------------------------------------------------------
    Signal HUsbDataEnable : Std_Logic;
    Signal HUsbDataOut    : Std_Logic_Vector( 7 Downto 0);

    Signal HUsbFlagDCsNOut : Std_Logic;

    Signal MemDatO        : Std_Logic_Vector(15 Downto 0);
    Signal MemDatI        : Std_Logic_Vector(15 Downto 0);
    Signal MemAdr         : Std_Logic_Vector( 7 Downto 0);
    Signal MemWe          : Std_Logic;

    Signal SnDatO         : Std_Logic_Vector(15 Downto 0);
    Signal SnDatI         : Std_Logic_Vector(15 Downto 0);
    Signal SnAdr          : Std_Logic_Vector( 7 Downto 0);
    Signal SnWe           : Std_Logic;

    Signal SpiMiso        : Std_Logic_Vector(30 Downto 0);
    Signal SpiMosi        : Std_Logic_Vector(30 Downto 0);
    Signal SpiClk         : Std_Logic_Vector(30 Downto 0);
    Signal SpiSel         : Std_Logic_Vector(30 Downto 0);

    Signal OneWireEnable  : Std_Logic;
    Signal OneWireDataOut : Std_Logic;
    -- -------------------------------------------------------------------------
    Signal Config_CLK_SCALER_VALUE        : Std_Logic_Vector(7 Downto 0);
    Signal Config_READ_STATUS_CYCLES      : Std_Logic_Vector(7 Downto 0);
    Signal Config_TM_ADDRESS_SETUP_CYCLES : Std_Logic_Vector(7 Downto 0);
    Signal Config_TM_RESET_CYCLES         : Std_Logic_Vector(7 Downto 0);
    Signal Config_TM_STROBE_HIGH_CYCLES   : Std_Logic_Vector(7 Downto 0);
    Signal Config_TM_STROBE_LOW_CYCLES    : Std_Logic_Vector(7 Downto 0);
    Signal Config_TM_WRITE_HIGH_CYCLES    : Std_Logic_Vector(7 Downto 0);
    -- -------------------------------------------------------------------------

-- -----------------------------------------------------------------------------
Begin
-- -----------------------------------------------------------------------------

    -- -------------------------------------------------------------------------
    Config_CLK_SCALER_VALUE        <= ReplaceWith_Config_ClkScalerValue;

    Config_READ_STATUS_CYCLES      <= ReplaceWith_Config_ReadStatusCycles;
    Config_TM_ADDRESS_SETUP_CYCLES <= ReplaceWith_Config_TmAddressSetupCycles;
    Config_TM_RESET_CYCLES         <= ReplaceWith_Config_TmResetCycles;
    Config_TM_STROBE_HIGH_CYCLES   <= ReplaceWith_Config_TmStrobeHighCycles;
    Config_TM_STROBE_LOW_CYCLES    <= ReplaceWith_Config_TmStrobeLowCycles;
    Config_TM_WRITE_HIGH_CYCLES    <= ReplaceWith_Config_TmWriteHighCycles;
    -- -------------------------------------------------------------------------

    -- -------------------------------------------------------------------------
    USB_D    <= HUsbDataOut    When HUsbDataEnable='1' Else (OTHERS => 'Z');
    ONE_WIRE <= OneWireDataOut When OneWireEnable ='1' Else 'Z';
    USB_FLAGD_CS_N <= HUsbFlagDCsNOut;
    -- -------------------------------------------------------------------------

    -- -------------------------------------------------------------------------
    --ReplaceWith_SpiDevicesAssignment
    -- -------------------------------------------------------------------------
    
    -- -------------------------------------------------------------------------
    U_ReplaceWith_EntityName_PC_INTERFACE_OWM : PC_INTERFACE_OWM Port Map (
        CLK_I                          => CLK_I,
        RST_I                          => RST_I,
        CONFIG_CLK_SCALER_VALUE        => Config_CLK_SCALER_VALUE,
        CONFIG_READ_STATUS_CYCLES      => Config_READ_STATUS_CYCLES,
        CONFIG_TM_ADDRESS_SETUP_CYCLES => Config_TM_ADDRESS_SETUP_CYCLES,
        CONFIG_TM_RESET_CYCLES         => Config_TM_RESET_CYCLES,
        CONFIG_TM_STROBE_HIGH_CYCLES   => Config_TM_STROBE_HIGH_CYCLES,
        CONFIG_TM_STROBE_LOW_CYCLES    => Config_TM_STROBE_LOW_CYCLES,
        CONFIG_TM_WRITE_HIGH_CYCLES    => Config_TM_WRITE_HIGH_CYCLES,
        DB_SPI_CLK                     => DB_SPI_CLK,
        DB_SPI_MISO                    => DB_SPI_DOUT,
        DB_SPI_MODE                    => DB_SPI_MODE,
        DB_SPI_MOSI                    => DB_SPI_DIN,
        DB_SPI_SEL                     => DB_SPI_SEL,
        HUSB_D_EN                      => HUsbDataEnable,
        HUSB_D_IN                      => USB_D,
        HUSB_D_OUT                     => HUsbDataOut,
        HUSB_FIFOADR0                  => USB_FIFOADR0,
        HUSB_FIFOADR1                  => USB_FIFOADR1,
        HUSB_FIFOADR2                  => USB_FIFOADR2,
        HUSB_FLAGA                     => USB_FLAGA,
        HUSB_FLAGB                     => USB_FLAGB,
        HUSB_FLAGC                     => USB_FLAGC,
        HUSB_FLAGD_CS_N                => HUsbFlagDCsNOut,
        HUSB_IFCLK                     => USB_IFCLK,
        HUSB_INT_N                     => USB_INT_N,
        HUSB_PKTEND                    => USB_PKTEND,
        HUSB_RD_N                      => USB_RD_N,
        HUSB_READY                     => USB_READY,
        HUSB_RESET_N                   => USB_RESET_N,
        HUSB_SLOE                      => USB_SLOE,
        HUSB_VBUS                      => USB_VBUS,
        HUSB_WR_N                      => USB_WR_N,
        JTAG_SOFT_TCK                  => JTAG_SOFT_TCK,
        JTAG_SOFT_TDI                  => JTAG_SOFT_TDI,
        JTAG_SOFT_TDO                  => JTAG_SOFT_TDO,
        JTAG_SOFT_TMS                  => JTAG_SOFT_TMS,
        MEM_DAT_ADR                    => MemAdr,
        MEM_DAT_I                      => MemDatI,
        MEM_DAT_O                      => MemDatO,
        MEM_WE_O                       => MemWe,
        ONE_WIRE_EN                    => OneWireEnable,
        ONE_WIRE_IN                    => ONE_WIRE,
        ONE_WIRE_OUT                   => OneWireDataOut,
        SN_ADR_O                       => SnAdr,
        SN_DAT_I                       => SnDatI,
        SN_DAT_O                       => SnDatO,
        SN_WE_O                        => SnWe,
        SPI_CLK                        => SpiClk,
        SPI_MISO                       => SpiMiso,
        SPI_MOSI                       => SpiMosi,
        SPI_SEL                        => SpiSel
    );
    -- -------------------------------------------------------------------------

    -- -------------------------------------------------------------------------
    U_ReplaceWith_EntityName_USB_DESCR_MEMORY : ReplaceWith_EntityName_USB_DESCR_MEMORY Port Map (
        CLKA  => CLK_I,
        DINA  => MemDatO,
        DOUTA => MemDatI,
        ADDRA => MemAdr,
        WEA   => MemWe,
        CLKB  => CLK_I,
        DINB  => SnDatO,
        DOUTB => SnDatI,
        ADDRB => SnAdr,
        WEB   => SnWe
    );
    -- -------------------------------------------------------------------------

-- -----------------------------------------------------------------------------
End RTL;
-- -----------------------------------------------------------------------------

